@@ -177,7 +177,7 @@ def ansible_template(
     """Render a templated string by mocking missing filters.
 
     In the case of a missing lookup, ansible core does an early exit
-    when disable_lookup=True but this happens after the jinja2 syntax already passed
+    but this happens after the jinja2 syntax already passed
     return the original string as if it had been templated.
 
     In the case of a missing filter, extract the missing filter plugin name
@@ -201,7 +201,6 @@ def ansible_template(
     re_valid_filter = re.compile(r"^\w+(\.\w+\.\w+)?$")
     templar = ansible_templar(basedir=basedir, templatevars=templatevars)
 
-    kwargs["disable_lookups"] = True
     for _i in range(10):
         try:
             if TrustedAsTemplate and not isinstance(varname, TrustedAsTemplate):
@@ -523,11 +522,11 @@ class HandleChildren:
             for loc in self.app.runtime.config.collections_paths:
                 append_playbook_path(
                     loc,
-                    playbook_path[:-1] + [f"{playbook_path[-1]}.yml"],
+                    [*playbook_path[:-1], f"{playbook_path[-1]}.yml"],
                 )
                 append_playbook_path(
                     loc,
-                    playbook_path[:-1] + [f"{playbook_path[-1]}.yaml"],
+                    [*playbook_path[:-1], f"{playbook_path[-1]}.yaml"],
                 )
         else:
             possible_paths.append(lintable.path.parent / v)
@@ -568,22 +567,29 @@ class HandleChildren:
 
     def _rolepath(self, basedir: str, role: str) -> str | None:
         role_path = None
-        namespace_name, collection_name, role_name = parse_fqcn(role)
+        namespace_name, collection_name, *role_name = parse_fqcn(role)
 
         possible_paths = [
             # if included from a playbook
-            path_dwim(basedir, os.path.join("roles", role_name)),
-            path_dwim(basedir, role_name),
+            path_dwim(basedir, os.path.join("roles", role_name[-1])),
+            path_dwim(basedir, role_name[-1]),
             # if included from roles/[role]/meta/main.yml
-            path_dwim(basedir, os.path.join("..", "..", "..", "roles", role_name)),
-            path_dwim(basedir, os.path.join("..", "..", role_name)),
+            path_dwim(basedir, os.path.join("..", "..", "..", "roles", role_name[-1])),
+            path_dwim(basedir, os.path.join("..", "..", role_name[-1])),
             # if checking a role in the current directory
-            path_dwim(basedir, os.path.join("..", role_name)),
+            path_dwim(basedir, os.path.join("..", role_name[-1])),
         ]
+        if len(role_name) > 1:
+            # This ignores deeper structures than 1 level
+            possible_paths.append(path_dwim(basedir, os.path.join("roles", *role_name)))
+            possible_paths.append(path_dwim(basedir, os.path.join(*role_name)))
+            possible_paths.append(
+                path_dwim(basedir, os.path.join("..", "..", *role_name))
+            )
 
         for loc in self.app.runtime.config.default_roles_path:
             loc = os.path.expanduser(loc)
-            possible_paths.append(path_dwim(loc, role_name))
+            possible_paths.append(path_dwim(loc, role_name[-1]))
 
         if namespace_name and collection_name:
             for loc in get_app(cached=True).runtime.config.collections_paths:
@@ -596,7 +602,7 @@ class HandleChildren:
                             namespace_name,
                             collection_name,
                             "roles",
-                            role_name,
+                            role_name[-1],
                         ),
                     ),
                 )
@@ -704,11 +710,12 @@ def _extract_ansible_parsed_keys_from_task(
     return result
 
 
-def normalize_task_v2(task: Task) -> dict[str, Any]:
+def normalize_task_v2(task: Task) -> MutableMapping[str, Any]:
     """Ensure tasks have a normalized action key and strings are converted to python objects."""
     raw_task = task.raw_task
-    result: dict[str, Any] = {}
+    result: MutableMapping[str, Any] = {}
     ansible_parsed_keys = ("action", "local_action", "args", "delegate_to")
+    arguments = {}
 
     if is_nested_task(raw_task):
         _extract_ansible_parsed_keys_from_task(result, raw_task, ansible_parsed_keys)
@@ -728,19 +735,32 @@ def normalize_task_v2(task: Task) -> dict[str, Any]:
             skip_action_validation=options.skip_action_validation,
         )
     except AnsibleParserError as exc:  # pragma: no cover
-        line = 0
-        column = 0
-        regex = LINE_COLUMN_REGEX.search(exc.message)
-        if regex:
-            line = int(regex.group("line"))
-            column = int(regex.group("column"))
-        raise MatchError(
-            rule=AnsibleParserErrorRule(),
-            message=exc.message,
-            lintable=Lintable(task.filename or ""),
-            lineno=line or raw_task.get(LINE_NUMBER_KEY, 1),
-            column=column or None,
-        ) from exc
+        if "get_line_column" not in globals():
+            from ansiblelint.yaml_utils import get_line_column
+        # pylint: disable=possibly-used-before-assignment
+        line, column = get_line_column(raw_task, 0)
+        if not line:
+            line = 0
+            column = 0
+            regex = LINE_COLUMN_REGEX.search(exc.message)
+            if regex:
+                line = int(regex.group("line"))
+                column = int(regex.group("column"))
+        if not exc.message.startswith(
+            "Complex args containing variables cannot use bare variables"
+        ):
+            raise MatchError(
+                rule=AnsibleParserErrorRule(),
+                message=exc.message,
+                lintable=Lintable(task.filename or ""),
+                lineno=line or 1,
+                column=column or None,
+            ) from exc
+        result = sanitized_task
+        if "action" not in result:
+            msg = "Unable to normalize task"
+            raise NotImplementedError(msg) from exc
+        action = result["action"]
 
     # denormalize shell -> command conversion
     if "_uses_shell" in arguments:
@@ -1146,8 +1166,8 @@ def parse_yaml_linenumbers(
         yaml.constructor.ConstructorError,
         ruamel.yaml.parser.ParserError,
     ) as exc:
-        msg = f"Failed to load YAML file: {lintable.path}"
-        raise RuntimeError(msg) from exc
+        msg = "Failed to load YAML file"
+        raise RuntimeError(msg, lintable.path) from exc
 
     if len(result) == 0:
         return None  # empty documents
@@ -1200,6 +1220,7 @@ def is_playbook(filename: str) -> bool:
         "gather_facts",
         "hosts",
         "import_playbook",
+        "ansible.builtin.import_playbook",
         "post_tasks",
         "pre_tasks",
         "roles",
@@ -1328,4 +1349,7 @@ def load_plugin(name: str) -> PluginLoadContext:
 
 def parse_fqcn(name: str) -> tuple[str, ...]:
     """Parse name parameter into FQCN segments."""
-    return tuple(name.split(".")) if is_fqcn(name) else ("", "", name)
+    if not is_fqcn(name):
+        return ("", "", name)
+
+    return tuple(name.split("."))
